==> 2.0.0.tar.gz: android/src/main/java/io/hackle/hackle/MethodParser.java <==
package io.hackle.hackle;

import static io.hackle.hackle.Constants.Method.FEATURE_FLAG_DETAIL;
import static io.hackle.hackle.Constants.Method.GET_DEVICE_ID;
import static io.hackle.hackle.Constants.Method.INITIALIZE;
import static io.hackle.hackle.Constants.Method.IS_FEATURE_ON;
import static io.hackle.hackle.Constants.Method.REMOTE_CONFIG_GET_BOOL;
import static io.hackle.hackle.Constants.Method.REMOTE_CONFIG_GET_DOUBLE;
import static io.hackle.hackle.Constants.Method.REMOTE_CONFIG_GET_INT;
import static io.hackle.hackle.Constants.Method.REMOTE_CONFIG_GET_STRING;
import static io.hackle.hackle.Constants.Method.TRACK;
import static io.hackle.hackle.Constants.Method.VARIATION;
import static io.hackle.hackle.Constants.Method.VARIATION_DETAIL;

import android.content.Context;

import androidx.annotation.NonNull;

import io.flutter.plugin.common.MethodChannel.Result;
import io.hackle.sdk.common.Variation;
import io.hackle.sdk.common.decision.Decision;
import io.hackle.sdk.common.decision.FeatureFlagDecision;


public class MethodParser {
    private final HackleAppWrapper hackleAppWrapper;

    MethodParser(Context context) {
        this.hackleAppWrapper = new HackleAppWrapper(context);
    }

    public void onMethodCall(@NonNull String method, @NonNull Object arguments, @NonNull Result result) {
        switch (method) {
            case INITIALIZE:
                hackleAppWrapper.initialize(arguments, () -> {
                    result.success(null);
                });
                break;
            case VARIATION:
                result.success(hackleAppWrapper.variation(arguments));
                break;
            case VARIATION_DETAIL:
                result.success(hackleAppWrapper.variationDetail(arguments));
                break;
            case IS_FEATURE_ON:
                result.success(hackleAppWrapper.isFeatureOn(arguments));
                break;
            case FEATURE_FLAG_DETAIL:
                result.success(hackleAppWrapper.featureFlagDetail(arguments));
                break;
            case TRACK:
                hackleAppWrapper.track(arguments);
                result.success(null);
                break;
            case GET_DEVICE_ID:
                result.success(hackleAppWrapper.getDeviceId());
                break;
            case REMOTE_CONFIG_GET_STRING:
                result.success(hackleAppWrapper.remoteConfigGetString(arguments));
                break;
            case REMOTE_CONFIG_GET_BOOL:
                result.success(hackleAppWrapper.remoteConfigGetBool(arguments));
                break;
            case REMOTE_CONFIG_GET_DOUBLE:
                result.success(hackleAppWrapper.remoteConfigGetDouble(arguments));
                break;
            case REMOTE_CONFIG_GET_INT:
                result.success(hackleAppWrapper.remoteConfigGetInt(arguments));
                break;
            default:
                result.notImplemented();
        }
    }
}

==> 2.1.0.tar.gz: android/src/main/java/io/hackle/hackle/MethodParser.java <==
package io.hackle.hackle;

import static io.hackle.hackle.Constants.Method.FEATURE_FLAG_DETAIL;
import static io.hackle.hackle.Constants.Method.GET_DEVICE_ID;
import static io.hackle.hackle.Constants.Method.GET_USER;
import static io.hackle.hackle.Constants.Method.INITIALIZE;
import static io.hackle.hackle.Constants.Method.IS_FEATURE_ON;
import static io.hackle.hackle.Constants.Method.REMOTE_CONFIG_GET_BOOL;
import static io.hackle.hackle.Constants.Method.REMOTE_CONFIG_GET_DOUBLE;
import static io.hackle.hackle.Constants.Method.REMOTE_CONFIG_GET_INT;
import static io.hackle.hackle.Constants.Method.REMOTE_CONFIG_GET_STRING;
import static io.hackle.hackle.Constants.Method.RESET_USER;
import static io.hackle.hackle.Constants.Method.SET_DEVICE_ID;
import static io.hackle.hackle.Constants.Method.SET_USER;
import static io.hackle.hackle.Constants.Method.SET_USER_ID;
import static io.hackle.hackle.Constants.Method.SET_USER_PROPERTY;
import static io.hackle.hackle.Constants.Method.TRACK;
import static io.hackle.hackle.Constants.Method.VARIATION;
import static io.hackle.hackle.Constants.Method.VARIATION_DETAIL;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;

import androidx.annotation.NonNull;

import io.flutter.plugin.common.MethodChannel.Result;
import io.hackle.sdk.common.Variation;
import io.hackle.sdk.common.decision.Decision;
import io.hackle.sdk.common.decision.FeatureFlagDecision;


public class MethodParser {
    private final HackleAppWrapper hackleAppWrapper;
    private final Handler uiThreadHandler = new Handler(Looper.getMainLooper());

    MethodParser(Context context) {
        this.hackleAppWrapper = new HackleAppWrapper(context);
    }

    public void onMethodCall(@NonNull String method, @NonNull Object arguments, @NonNull Result result) {
        switch (method) {
            case INITIALIZE:
                hackleAppWrapper.initialize(arguments, () -> uiThreadHandler.post(() -> {
                    result.success(null);
                }));
                break;
            case VARIATION:
                result.success(hackleAppWrapper.variation(arguments));
                break;
            case VARIATION_DETAIL:
                result.success(hackleAppWrapper.variationDetail(arguments));
                break;
            case IS_FEATURE_ON:
                result.success(hackleAppWrapper.isFeatureOn(arguments));
                break;
            case FEATURE_FLAG_DETAIL:
                result.success(hackleAppWrapper.featureFlagDetail(arguments));
                break;
            case TRACK:
                hackleAppWrapper.track(arguments);
                result.success(null);
                break;
            case GET_DEVICE_ID:
                result.success(hackleAppWrapper.getDeviceId());
                break;
            case SET_DEVICE_ID:
                hackleAppWrapper.setDeviceId(arguments);
                result.success(null);
                break;
            case GET_USER:
                result.success(hackleAppWrapper.getUser());
                break;
            case SET_USER:
                hackleAppWrapper.setUser(arguments);
                result.success(null);
                break;
            case SET_USER_ID:
                hackleAppWrapper.setUserId(arguments);
                result.success(null);
                break;
            case SET_USER_PROPERTY:
                hackleAppWrapper.setUserProperty(arguments);
                result.success(null);
                break;
            case RESET_USER:
                hackleAppWrapper.resetUser();
                result.success(null);
                break;
            case REMOTE_CONFIG_GET_STRING:
                result.success(hackleAppWrapper.remoteConfigGetString(arguments));
                break;
            case REMOTE_CONFIG_GET_BOOL:
                result.success(hackleAppWrapper.remoteConfigGetBool(arguments));
                break;
            case REMOTE_CONFIG_GET_DOUBLE:
                result.success(hackleAppWrapper.remoteConfigGetDouble(arguments));
                break;
            case REMOTE_CONFIG_GET_INT:
                result.success(hackleAppWrapper.remoteConfigGetInt(arguments));
                break;
            default:
                result.notImplemented();
        }
    }
}
